@@ -41,6 +41,14 @@ GST_DEBUG_CATEGORY_EXTERN (GST_CAT_SEEK);
  */
 #define MP_SCR_RATE_HYST 0.08
 
+/* elementfactory information */
+static GstElementDetails mpeg_parse_details = {
+  "MPEG System Parser",
+  "Codec/Parser",
+  "Parses MPEG1 and MPEG2 System Streams",
+  "Erik Walthinsen <omega@cse.ogi.edu>\n" "Wim Taymans <wim.taymans@chello.be>"
+};
+
 #define CLASS(o)        GST_MPEG_PARSE_CLASS (G_OBJECT_GET_CLASS (o))
 
 #define DEFAULT_MAX_SCR_GAP     120000
@@ -82,6 +90,7 @@ static GstStaticPadTemplate src_factory = GST_STATIC_PAD_TEMPLATE ("src",
 GST_BOILERPLATE_FULL (GstMPEGParse, gst_mpeg_parse, GstElement,
     GST_TYPE_ELEMENT, _do_init);
 
+static void gst_mpeg_parse_class_init (GstMPEGParseClass * klass);
 static GstStateChangeReturn gst_mpeg_parse_change_state (GstElement * element,
     GstStateChange transition);
 
@@ -119,10 +128,7 @@ gst_mpeg_parse_base_init (gpointer klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_set_details_simple (element_class, "MPEG System Parser",
-      "Codec/Parser",
-      "Parses MPEG1 and MPEG2 System Streams",
-      "Erik Walthinsen <omega@cse.ogi.edu>, Wim Taymans <wim.taymans@chello.be>");
+  gst_element_class_set_details (element_class, &mpeg_parse_details);
 }
 
 static void
@@ -161,26 +167,24 @@ gst_mpeg_parse_class_init (GstMPEGParseClass * klass)
   /* FIXME: this is a hack.  We add the pad templates here instead
    * in the base_init function, since the derived class (mpegdemux)
    * uses different pads.  IMO, this is wrong. */
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &src_factory);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &sink_factory);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&src_factory));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&sink_factory));
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MAX_SCR_GAP,
-      g_param_spec_int ("max-scr-gap", "Max SCR gap",
+      g_param_spec_int ("max_scr_gap", "Max SCR gap",
           "Maximum allowed gap between expected and actual "
           "SCR values. -1 means never adjust.", -1, G_MAXINT,
-          DEFAULT_MAX_SCR_GAP, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          DEFAULT_MAX_SCR_GAP, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_BYTE_OFFSET,
       g_param_spec_uint64 ("byte-offset", "Byte Offset",
           "Emit reached-offset signal when the byte offset is reached.",
-          0, G_MAXUINT64, G_MAXUINT64,
-          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          0, G_MAXUINT64, G_MAXUINT64, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_TIME_OFFSET,
       g_param_spec_uint64 ("time-offset", "Time Offset",
           "Time offset in the stream.",
-          0, G_MAXUINT64, G_MAXUINT64,
-          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+          0, G_MAXUINT64, G_MAXUINT64, G_PARAM_READABLE));
 }
 
 static void
@@ -379,16 +383,9 @@ gst_mpeg_parse_process_event (GstMPEGParse * mpeg_parse, GstEvent * event)
           if (CLASS (mpeg_parse)->send_event) {
             CLASS (mpeg_parse)->send_event (mpeg_parse,
                 gst_event_new_new_segment (FALSE, rate, GST_FORMAT_TIME,
-                    start, stop, time));
-            mpeg_parse->pending_newsegment = FALSE;
+                    start, -1, time));
           }
         }
-      } else if (format != GST_FORMAT_TIME && !update) {
-        GST_DEBUG_OBJECT (mpeg_parse,
-            "Received non-time newsegment from stream");
-        mpeg_parse->do_adjust = TRUE;
-        mpeg_parse->adjust = 0;
-        mpeg_parse->pending_newsegment = TRUE;
       }
       mpeg_parse->packetize->resync = TRUE;
 
@@ -410,20 +407,9 @@ gst_mpeg_parse_process_event (GstMPEGParse * mpeg_parse, GstEvent * event)
       gst_mpeg_packetize_flush_cache (mpeg_parse->packetize);
       break;
     }
-    case GST_EVENT_EOS:{
+    case GST_EVENT_EOS:
       GST_DEBUG_OBJECT (mpeg_parse, "EOS");
-
-      if (CLASS (mpeg_parse)->send_event) {
-        ret = CLASS (mpeg_parse)->send_event (mpeg_parse, event);
-      } else {
-        gst_event_unref (event);
-      }
-      if (!ret) {
-        GST_ELEMENT_ERROR (mpeg_parse, STREAM, DEMUX, (NULL),
-            ("Pushing EOS event didn't work on any of the source pads"));
-      }
-      break;
-    }
+      /* fall through to default handler */
     default:
       if (CLASS (mpeg_parse)->send_event) {
         ret = CLASS (mpeg_parse)->send_event (mpeg_parse, event);
@@ -436,13 +422,12 @@ gst_mpeg_parse_process_event (GstMPEGParse * mpeg_parse, GstEvent * event)
   return ret;
 }
 
-/* returns TRUE if pushing the event worked on at least one pad */
 static gboolean
 gst_mpeg_parse_send_event (GstMPEGParse * mpeg_parse, GstEvent * event)
 {
   GstIterator *it;
   gpointer pad;
-  gboolean ret = FALSE;
+  gboolean ret = TRUE;
 
   /* Send event to all source pads of this element. */
   it = gst_element_iterate_src_pads (GST_ELEMENT (mpeg_parse));
@@ -450,8 +435,7 @@ gst_mpeg_parse_send_event (GstMPEGParse * mpeg_parse, GstEvent * event)
     switch (gst_iterator_next (it, &pad)) {
       case GST_ITERATOR_OK:
         gst_event_ref (event);
-        if (gst_pad_push_event (GST_PAD (pad), event))
-          ret = TRUE;
+        gst_pad_push_event (GST_PAD (pad), event);
         gst_object_unref (GST_OBJECT (pad));
         break;
       case GST_ITERATOR_RESYNC:
@@ -491,7 +475,7 @@ gst_mpeg_parse_pad_added (GstElement * element, GstPad * pad)
   event = gst_event_new_new_segment (FALSE,
       mpeg_parse->current_segment.rate,
       GST_FORMAT_TIME, mpeg_parse->current_segment.start,
-      mpeg_parse->current_segment.stop, mpeg_parse->current_segment.start);
+      -1, mpeg_parse->current_segment.start);
 
   gst_pad_push_event (pad, event);
 }
@@ -508,8 +492,8 @@ gst_mpeg_parse_parse_packhead (GstMPEGParse * mpeg_parse, GstBuffer * buffer)
   buf = GST_BUFFER_DATA (buffer);
   buf += 4;
 
-  scr1 = GST_READ_UINT32_BE (buf);
-  scr2 = GST_READ_UINT32_BE (buf + 4);
+  scr1 = GUINT32_FROM_BE (*(guint32 *) buf);
+  scr2 = GUINT32_FROM_BE (*(guint32 *) (buf + 4));
 
   /* Extract the SCR and rate values from the header. */
   if (GST_MPEG_PACKETIZE_IS_MPEG2 (mpeg_parse->packetize)) {
@@ -778,18 +762,17 @@ gst_mpeg_parse_chain (GstPad * pad, GstBuffer * buffer)
     /* Make sure the output pad has proper capabilities. */
     if (!GST_PAD_CAPS (mpeg_parse->sinkpad)) {
       gboolean mpeg2 = GST_MPEG_PACKETIZE_IS_MPEG2 (mpeg_parse->packetize);
-      GstCaps *caps = gst_caps_new_simple ("video/mpeg",
-          "mpegversion", G_TYPE_INT, (mpeg2 ? 2 : 1),
-          "systemstream", G_TYPE_BOOLEAN, TRUE,
-          "parsed", G_TYPE_BOOLEAN, TRUE, NULL);
-      if (!gst_pad_set_caps (mpeg_parse->sinkpad, caps) < 0) {
+
+      if (!gst_pad_set_caps (mpeg_parse->sinkpad,
+              gst_caps_new_simple ("video/mpeg",
+                  "mpegversion", G_TYPE_INT, (mpeg2 ? 2 : 1),
+                  "systemstream", G_TYPE_BOOLEAN, TRUE,
+                  "parsed", G_TYPE_BOOLEAN, TRUE, NULL)) < 0) {
         GST_ELEMENT_ERROR (mpeg_parse, CORE, NEGOTIATION, (NULL), (NULL));
         gst_buffer_unref (buffer);
         result = GST_FLOW_ERROR;
-        gst_caps_unref (caps);
         break;
       }
-      gst_caps_unref (caps);
     }
 
     /* Send the buffer. */
@@ -839,7 +822,7 @@ gst_mpeg_parse_chain (GstPad * pad, GstBuffer * buffer)
           ", total since SCR: %" G_GINT64_FORMAT ", br: %" G_GINT64_FORMAT
           ", next SCR: %" G_GINT64_FORMAT, size, bss, br, mpeg_parse->next_scr);
     }
-  } while (result == GST_FLOW_OK);
+  } while (GST_FLOW_IS_SUCCESS (result));
 
   if (result != GST_FLOW_OK) {
     GST_DEBUG_OBJECT (mpeg_parse, "flow: %s", gst_flow_get_name (result));
@@ -1026,6 +1009,7 @@ gst_mpeg_parse_handle_src_query (GstPad * pad, GstQuery * query)
           src_format = GST_FORMAT_TIME;
           if (gst_pad_query_peer_duration (mpeg_parse->sinkpad,
                   &src_format, &src_value)) {
+            res = TRUE;
             break;
           }
           /* Otherwise fallthrough */
@@ -1041,8 +1025,6 @@ gst_mpeg_parse_handle_src_query (GstPad * pad, GstQuery * query)
 
       /* Convert the value to the desired format. */
       if ((res = gst_mpeg_parse_convert (mpeg_parse, src_format, src_value,
-                  &format, &value)) ||
-          (res = gst_pad_query_peer_duration (mpeg_parse->sinkpad,
                   &format, &value))) {
         gst_query_set_duration (query, format, value);
       }
@@ -1072,8 +1054,6 @@ gst_mpeg_parse_handle_src_query (GstPad * pad, GstQuery * query)
 
       /* Convert the value to the desired format. */
       if ((res = gst_mpeg_parse_convert (mpeg_parse, src_format, src_value,
-                  &format, &value)) ||
-          (res = gst_pad_query_peer_position (mpeg_parse->sinkpad,
                   &format, &value))) {
         gst_query_set_position (query, format, value);
       }
@@ -1083,9 +1063,7 @@ gst_mpeg_parse_handle_src_query (GstPad * pad, GstQuery * query)
       gst_query_parse_convert (query, &src_format, &src_value, &format, NULL);
 
       if ((res = gst_mpeg_parse_convert (mpeg_parse, src_format, src_value,
-                  &format, &value)) ||
-          (res = gst_pad_query_peer_convert (mpeg_parse->sinkpad,
-                  src_format, src_value, &format, &value))) {
+                  &format, &value))) {
         gst_query_set_convert (query, src_format, src_value, format, value);
       }
       break;
@@ -1161,8 +1139,7 @@ normal_seek (GstMPEGParse * mpeg_parse, GstPad * pad, GstEvent * event)
       goto done;
     }
     GST_INFO_OBJECT (mpeg_parse,
-        "Finished conversion of cur, BYTES cur : %" G_GINT64_FORMAT,
-        start_position);
+        "Finished conversion of cur, BYTES cur : %lld", start_position);
   } else {
     start_position = -1;
   }
@@ -1182,8 +1159,7 @@ normal_seek (GstMPEGParse * mpeg_parse, GstPad * pad, GstEvent * event)
       goto done;
     }
     GST_INFO_OBJECT (mpeg_parse,
-        "Finished conversion of stop, BYTES stop : %" G_GINT64_FORMAT,
-        end_position);
+        "Finished conversion of stop, BYTES stop : %lld", end_position);
   } else {
     end_position = -1;
   }
